@@ -53,6 +53,7 @@ class StoreMixin:
         stores = response_data['result_data']['poi_section']['list']
         for store in stores:
             store['_id'] = store['v_rid']
+            store['id'] = store['v_rid']
         return stores
 
     def _parse_address(self, address_container_soup):
@@ -230,10 +231,10 @@ class StoreMixin:
         else:
             return False
 
-    def get_banners(self, code: str, proxy:None):
+    def get_banners(self, code: str, proxies = None):
         response = requests.get(f'https://www.diningcode.com/2018/ajax/gallery.php?rid={code}',
                                 headers=HEADERS,
-                                proxies=proxy
+                                proxies=proxies
                                 )
         soup = BeautifulSoup(response.text, 'html.parser')
         banner_container_tag_soup = soup.find("ul", class_="gallery-thumb-list")
@@ -241,7 +242,7 @@ class StoreMixin:
 
         return banner_urls
 
-    def get_store(self, code: str, proxies: None):
+    def get_store(self, code: str, proxies = None):
         response = requests.post(f'https://www.diningcode.com/profile.php?rid={code}',
                                  headers=HEADERS,
                                  proxies=proxies
